@@ -11,11 +11,11 @@ madElev <- fastData("madElev")
 elev <- fast(madElev)
 
 ### Create a raster with values drawn from a uniform distribution:
-unif <- runifRast(elev)
+unif <- rUnifRast(elev)
 plot(unif)
 
 ### Create a raster with values drawn from a normal distribution:
-norms <- rnormRast(elev, n = 2, mu = c(5, 10), sigma = c(2, 1))
+norms <- rNormRast(elev, n = 2, mu = c(5, 10), sigma = c(2, 1))
 plot(norms)
 hist(norms, bins = 100)
 
@@ -34,4 +34,23 @@ fractal <- fractalRast(elev, n = 2, dimension = c(2.1, 2.8))
 plot(fractal)
 hist(fractal)
 
+### Random walker rasters
+
+# One random walker
+walk <- rWalkRast(elev)
+plot(walk)
+
+# Random walker with self-avoidance:
+walkAvoid <- rWalkRast(elev, steps = 1000, avoid = TRUE, seed = 1)
+plot(walkAvoid)
+
+# 10 random walkers:
+walk10 <- rWalkRast(elev, n = 10)
+plot(walk10)
+
+# 10 random walkers starting in same place:
+walkSame10 <- rWalkRast(elev, n = 10, sameStart = TRUE)
+plot(walkSame10)
+
+
 }
